==> faas-0.0.24.tgz: package/ix-server/crypto.js <==
var crypto = require('crypto')

var SALT_HEX = '985ceb6dcec614f4a6cb156e7e2a14398cf964b1568f4d2213b60a6449d7c1d9'
var SALT = new Buffer(SALT_HEX, 'hex')
var KEY = null

exports.setKey = function(key){
  KEY = key
}

exports.decrypt = function(cipherParams, cb_err_data){
  crypto.pbkdf2(KEY, SALT, 256, 256/8, function(err, key){
    if (err) { cb_err_data(err); return }
    try {
      var ivBuf = new Buffer(cipherParams.iv, 'hex')
      var decipher = crypto.createDecipheriv('aes-256-cbc', key, ivBuf)
      decipher.end(cipherParams.ct, 'hex')
      var plaintext = decipher.read().toString('utf8')
      var data = JSON.parse(plaintext.slice(16))
      cb_err_data(null, data)
    }
    catch(e) {
      cb_err_data(e)
    }
  })
}

exports.encryptingResponder = function(responder){
  return function(err, data){
    var ptParams = { err: err, data: data }
    crypto.pseudoRandomBytes(12, function(err, prefixBuf){ // 12 bytes
      if (err) { responder(err); return }
      var prefix = prefixBuf.toString('base64') // 16 chars
      var plaintext = prefix+JSON.stringify(ptParams)
      crypto.pbkdf2(KEY, SALT, 256, 256/8, function(err, key){
        if (err) { responder(err); return }
        crypto.pseudoRandomBytes(128/8, function(err, iv){
          if (err) { responder(err); return }
          var cipher = crypto.createCipheriv('aes-256-cbc', key, iv)
          cipher.end(plaintext)
          var ciphertext = ''
          var ctBuf = null
          while (ctBuf = cipher.read()) {
            ciphertext += ctBuf.toString('hex')
          }
          responder(null, { ct: ciphertext, iv: iv.toString('hex') })
        })
      })
    })
  }
}

==> faas-0.5.0.tgz: package/ix-server/crypto.js <==
var crypto = require('crypto')
var Base = require('../base')

var SALT_HEX = '985ceb6dcec614f4a6cb156e7e2a14398cf964b1568f4d2213b60a6449d7c1d9'
var SALT = new Buffer(SALT_HEX, 'hex')
var KEY = null

var getKey = function(){
  return (KEY || Base.env.IX_ENCRYPTION_KEY)
}

exports.setKey = function(key){
  KEY = key
}

exports.decrypt = function(cipherParams, cb_err_data){
  crypto.pbkdf2(getKey(), SALT, 256, 256/8, function(err, key){
    if (err) { cb_err_data(err); return }
    try {
      var ivBuf = new Buffer(cipherParams.iv, 'hex')
      var decipher = crypto.createDecipheriv('aes-256-cbc', key, ivBuf)
      decipher.end(cipherParams.ct, 'hex')
      var plaintext = decipher.read().toString('utf8')
      var data = JSON.parse(plaintext.slice(16))
      cb_err_data(null, data)
    }
    catch(e) {
      cb_err_data(e)
    }
  })
}

exports.encryptingResponder = function(responder){
  return function(err, data){
    var ptParams = { err: err, data: data }
    crypto.pseudoRandomBytes(12, function(err, prefixBuf){ // 12 bytes
      if (err) { responder(err); return }
      var prefix = prefixBuf.toString('base64') // 16 chars
      var plaintext = prefix+JSON.stringify(ptParams)
      crypto.pbkdf2(getKey(), SALT, 256, 256/8, function(err, key){
        if (err) { responder(err); return }
        crypto.pseudoRandomBytes(128/8, function(err, iv){
          if (err) { responder(err); return }
          var cipher = crypto.createCipheriv('aes-256-cbc', key, iv)
          cipher.end(plaintext)
          var ciphertext = ''
          var ctBuf = null
          while (ctBuf = cipher.read()) {
            ciphertext += ctBuf.toString('hex')
          }
          responder(null, { ct: ciphertext, iv: iv.toString('hex') })
        })
      })
    })
  }
}
